Welcome to pksetupunit2
=================

optional args like extras_require

.. toctree::
   :maxdepth: 2

   pksetupunit2
   modules

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
